==> aptechka-0.42.5.tgz: package/lib/iframe/index.js <==
var u = (r) => {
  throw TypeError(r);
};
var a = (r, t, e) => t.has(r) || u("Cannot " + e);
var s = (r, t, e) => (a(r, t, "read from private field"), e ? e.call(r) : t.get(r)), i = (r, t, e) => t.has(r) ? u("Cannot add the same private member more than once") : t instanceof WeakSet ? t.add(r) : t.set(r, e), c = (r, t, e, o) => (a(r, t, "write to private field"), o ? o.call(r, e) : t.set(r, e), e);
import { SourceElement as E } from "../source/index.js";
import "../window-resizer/index.js";
import "../Store-Cm3LPXlx.js";
var n, m, l;
class h extends E {
  constructor() {
    super({
      sourceSetOptions: {
        mediaBuckets: !1
      }
    });
    i(this, n, null);
    i(this, m, () => {
      var e, o;
      (o = (e = this.consumerElement).onload) == null || o.call(e, new Event("load"));
    });
    i(this, l, () => {
      var e, o;
      (o = (e = this.consumerElement).onload) == null || o.call(e, new Event("error"));
    });
  }
  createConsumer() {
    return document.createElement("div");
  }
  consumeSource(e) {
    s(this, n) && (s(this, n).onload = null, s(this, n).onerror = null), this.consumerElement.innerHTML = (e == null ? void 0 : e.replace(/\\u003C/g, "<").replace(/\\u003E/g, ">").replace(/\\"/g, '"')) || "", c(this, n, this.consumerElement.querySelector("iframe")), s(this, n) && (s(this, n).onload = s(this, m), s(this, n).onerror = s(this, l));
  }
}
n = new WeakMap(), m = new WeakMap(), l = new WeakMap();
customElements.get("e-iframe") || customElements.define("e-iframe", h);
export {
  h as IFrameElement
};

==> aptechka-0.44.1.tgz: package/lib/iframe/index.js <==
var a = (r) => {
  throw TypeError(r);
};
var u = (r, t, e) => t.has(r) || a("Cannot " + e);
var s = (r, t, e) => (u(r, t, "read from private field"), e ? e.call(r) : t.get(r)), i = (r, t, e) => t.has(r) ? a("Cannot add the same private member more than once") : t instanceof WeakSet ? t.add(r) : t.set(r, e), c = (r, t, e, o) => (u(r, t, "write to private field"), o ? o.call(r, e) : t.set(r, e), e);
import { SourceElement as E } from "../source/index.js";
import "../window-resizer/index.js";
import "../Store-D2xCXENW.js";
import { i as f } from "../index-euf5anj6.js";
var n, m, l;
class h extends E {
  constructor() {
    super({
      sourceSetOptions: {
        mediaBuckets: !1
      }
    });
    i(this, n, null);
    i(this, m, () => {
      var e, o;
      (o = (e = this.consumerElement).onload) == null || o.call(e, new Event("load"));
    });
    i(this, l, () => {
      var e, o;
      (o = (e = this.consumerElement).onload) == null || o.call(e, new Event("error"));
    });
  }
  createConsumer() {
    return document.createElement("div");
  }
  consumeSource(e) {
    s(this, n) && (s(this, n).onload = null, s(this, n).onerror = null), this.consumerElement.innerHTML = (e == null ? void 0 : e.replace(/\\u003C/g, "<").replace(/\\u003E/g, ">").replace(/\\"/g, '"')) || "", c(this, n, this.consumerElement.querySelector("iframe")), s(this, n) && (s(this, n).onload = s(this, m), s(this, n).onerror = s(this, l));
  }
}
n = new WeakMap(), m = new WeakMap(), l = new WeakMap();
f && !customElements.get("e-iframe") && customElements.define("e-iframe", h);
export {
  h as IFrameElement
};
